# Define before mingw-binutils is build
%bcond_with bootstrap

%global debug_package %{nil}

# Place RPM macros in %%{_rpmconfigdir}/macros.d if it exists (RPM 4.11+)
# Otherwise, use %%{_sysconfdir}/rpm
# https://lists.fedoraproject.org/pipermail/devel/2014-January/195026.html
%global macrosdir %(d=%{_rpmconfigdir}/macros.d; [ -d $d ] || d=%{_sysconfdir}/rpm; echo $d)

Name:           mingw-filesystem
Version:        148
Release:        %mkrel 1
Summary:        MinGW cross compiler base filesystem and environment

Group:          Development/Other
License:        GPLv2+
URL:            https://fedoraproject.org/wiki/MinGW
BuildArch:      noarch

Source0:        COPYING
Source1:        macros.mingw
Source2:        macros.mingw32
Source3:        macros.mingw64
Source4:        macros.ucrt64
Source5:        mingw32.sh
Source6:        mingw64.sh
Source7:        ucrt64.sh
Source8:        mingw-find-debuginfo.sh
Source9:        mingw.req
Source10:       mingw.prov
Source11:       mingw-scripts.sh
Source12:       mingw-rpmlint.config
Source13:       toolchain-mingw32.cmake
Source14:       toolchain-mingw64.cmake
Source15:       toolchain-ucrt64.cmake
Source16:       mingw-find-lang.sh
Source17:       mingw32.attr
Source18:       mingw64.attr
Source19:       ucrt64.attr
Source20:       toolchain-mingw32.meson
Source21:       toolchain-mingw64.meson
Source22:       toolchain-ucrt64.meson
Source23:       pkgconf-personality-mingw32
Source24:       pkgconf-personality-mingw64
Source25:       pkgconf-personality-ucrt64
Source26:       mingw32-hostlib.conf
Source27:       mingw64-hostlib.conf

# Taken from the Fedora filesystem package
Source101:      https://fedorahosted.org/filesystem/browser/lang-exceptions
Source102:      iso_639.sed
Source103:      iso_3166.sed

# (tv) explain the build order:
Source1000:	README.md

BuildRequires:  make
BuildRequires:  iso-codes
BuildRequires:  pkgconf


%description
This package contains the base filesystem layout, RPM macros and
environment for all Fedora MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  https://fedoraproject.org/wiki/SIGs/MinGW


%package base
Summary:        Generic files which are needed for {mingw32,mingw64,ucrt64}-filesystem

# We need this for cmake macros
Requires:       cmake-rpm-macros
Requires:       rpm-mageia-setup
# Obsolete the packages from the test repo
Obsoletes:      cross-filesystem < 67-2
Obsoletes:      cross-filesystem-scripts < 67-2
Obsoletes:      mingw-filesystem < 75-2
Obsoletes:      mingw-filesystem-scripts < 75-2
# For using pkgconf with MinGW
Requires:       pkgconf

%description base
This package contains the base filesystem layout, RPM macros and
environment for all Fedora MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  https://fedoraproject.org/wiki/SIGs/MinGW


%package -n mingw32-filesystem
Summary:        MinGW cross compiler base filesystem and environment for the win32 target
Requires:       %{name}-base = %{version}-%{release}
# Replace mingw32-pkg-config
Conflicts:      mingw32-pkg-config < 0.28-17
Obsoletes:      mingw32-pkg-config < 0.28-17
Provides:       mingw32-pkg-config = 0.28-17
%if %{without bootstrap}
Requires:       mingw-binutils-generic
%endif

%description -n mingw32-filesystem
This package contains the base filesystem layout, RPM macros and
environment for all Fedora MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  https://fedoraproject.org/wiki/SIGs/MinGW

%package -n mingw64-filesystem
Summary:        MinGW cross compiler base filesystem and environment for the win64 target
Requires:       %{name}-base = %{version}-%{release}
# Replace mingw64-pkg-config
Conflicts:      mingw64-pkg-config < 0.28-17
Obsoletes:      mingw64-pkg-config < 0.28-17
Provides:       mingw64-pkg-config = 0.28-17
%if %{without bootstrap}
Requires:       mingw-binutils-generic
%endif

%description -n mingw64-filesystem
This package contains the base filesystem layout, RPM macros and
environment for all Fedora MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  https://fedoraproject.org/wiki/SIGs/MinGW


%package -n ucrt64-filesystem
Summary:        MinGW cross compiler base filesystem and environment for the win64 UCRT target
Requires:       %{name}-base = %{version}-%{release}
# Replace ucrt64-pkg-config
Conflicts:      ucrt64-pkg-config < 0.28-17
Obsoletes:      ucrt64-pkg-config < 0.28-17
Provides:       ucrt64-pkg-config = 0.28-17
%if %{without bootstrap}
Requires:       mingw-binutils-generic
%endif

%description -n ucrt64-filesystem
This package contains the base filesystem layout, RPM macros and
environment for all Fedora MinGW packages.

This environment is maintained by the Fedora MinGW SIG at:

  https://fedoraproject.org/wiki/SIGs/MinGW


%prep
%setup -q -c -T
cp %{SOURCE0} COPYING


%build
# nothing


%install
mkdir -p %{buildroot}%{_libexecdir}
install -m 755 %{SOURCE11} %{buildroot}%{_libexecdir}/mingw-scripts

mkdir -p %{buildroot}%{_bindir}
pushd %{buildroot}%{_bindir}
for i in mingw32-configure mingw32-cmake mingw32-make mingw32-meson mingw32-pkg-config \
         mingw64-configure mingw64-cmake mingw64-make mingw64-meson mingw64-pkg-config \
         ucrt64-configure ucrt64-cmake ucrt64-make ucrt64-meson ucrt64-pkg-config ; do
  ln -s %{_libexecdir}/mingw-scripts $i
done
for i in i686-w64-mingw32-pkg-config  \
         x86_64-w64-mingw32-pkg-config \
         x86_64-w64-mingw32ucrt-pkg-config ; do
  ln -s %{_bindir}/pkgconf $i
done
popd

mkdir -p %{buildroot}%{_sysconfdir}/profile.d
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/
install -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/profile.d/
install -m 644 %{SOURCE7} %{buildroot}%{_sysconfdir}/profile.d/

mkdir -p %{buildroot}%{macrosdir}
install -m 644 %{SOURCE1} %{buildroot}%{macrosdir}/macros.mingw
install -m 644 %{SOURCE2} %{buildroot}%{macrosdir}/macros.mingw32
install -m 644 %{SOURCE3} %{buildroot}%{macrosdir}/macros.mingw64
install -m 644 %{SOURCE4} %{buildroot}%{macrosdir}/macros.ucrt64

mkdir -p %{buildroot}%{_sysconfdir}/rpmlint
install -m 644 %{SOURCE12} %{buildroot}%{_sysconfdir}/rpmlint/

for target in i686-w64-mingw32 x86_64-w64-mingw32 x86_64-w64-mingw32ucrt; do
  # Create the folders required for gcc and binutils
  mkdir -p %{buildroot}%{_prefix}/$target
  mkdir -p %{buildroot}%{_prefix}/$target/bin
  mkdir -p %{buildroot}%{_prefix}/$target/lib

  # The MinGW system root which will contain Windows native binaries
  # and Windows-specific header files, pkgconfig, etc.
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/bin
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/etc
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/include
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/include/sys
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/lib
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/lib/pkgconfig
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/lib/cmake
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/sbin

  # We don't normally package manual pages and info files, except
  # where those are not supplied by a Fedora native package.  So we
  # need to create the directories.
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/doc
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/info
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/man
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/man/man{1,2,3,4,5,6,7,8,l,n}
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/aclocal
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/themes
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/cmake
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/locale
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/pkgconfig
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/xml
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/icons
  mkdir -p %{buildroot}%{_prefix}/$target/sys-root/mingw/share/metainfo

  mkdir -p %{buildroot}%{_prefix}/lib/debug/%{_prefix}/$target
done

# Own folders for all locales
# Snippet taken from the Fedora filesystem package
sed -n -f %{SOURCE102} /usr/share/xml/iso-codes/iso_639.xml > %{buildroot}/iso_639.tab
sed -n -f %{SOURCE103} /usr/share/xml/iso-codes/iso_3166.xml > %{buildroot}/iso_3166.tab

grep -v "^$" %{buildroot}/iso_639.tab | grep -v "^#" | while read a b c d ; do
    [[ "$d" =~ "^Reserved" ]] && continue
    [[ "$d" =~ "^No linguistic" ]] && continue

    locale=$c
    if [ "$locale" = "XX" ]; then
        locale=$b
    fi
    echo "%lang(${locale}) %{_prefix}/i686-w64-mingw32/sys-root/mingw/share/locale/${locale}" >> filelist_mingw32
    echo "%lang(${locale}) %{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/locale/${locale}" >> filelist_mingw64
    echo "%lang(${locale}) %{_prefix}/x86_64-w64-mingw32ucrt/sys-root/mingw/share/locale/${locale}" >> filelist_ucrt
done

cat %{SOURCE101} | grep -v "^#" | grep -v "^$" | while read loc ; do
    locale=$loc
    locality=
    special=
    [[ "$locale" =~ "@" ]] && locale=${locale%%%%@*}
    [[ "$locale" =~ "_" ]] && locality=${locale##*_}
    [[ "$locality" =~ "." ]] && locality=${locality%%%%.*}
    [[ "$loc" =~ "_" ]] || [[ "$loc" =~ "@" ]] || special=$loc

    # If the locality is not official, skip it
    if [ -n "$locality" ]; then
        grep -q "^$locality" %{buildroot}/iso_3166.tab || continue
    fi
    # If the locale is not official and not special, skip it
    if [ -z "$special" ]; then
        grep -Eq "[[:space:]]${locale%%_*}[[:space:]]" %{buildroot}/iso_639.tab || continue
    fi
    echo "%lang(${locale}) %{_prefix}/i686-w64-mingw32/sys-root/mingw/share/locale/${loc}" >> filelist_mingw32
    echo "%lang(${locale}) %{_prefix}/x86_64-w64-mingw32/sys-root/mingw/share/locale/${loc}" >> filelist_mingw64
    echo "%lang(${locale}) %{_prefix}/x86_64-w64-mingw32ucrt/sys-root/mingw/share/locale/${loc}" >> filelist_ucrt
done

rm -f %{buildroot}/iso_639.tab
rm -f %{buildroot}/iso_3166.tab

cat filelist_mingw32 filelist_mingw64 filelist_ucrt | grep "locale" | while read a b ; do
    mkdir -p -m 755 %{buildroot}/$b/LC_MESSAGES
done

# NB. NOT _libdir
mkdir -p %{buildroot}/usr/lib/rpm
install -m 0755 %{SOURCE8} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE9} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE10} %{buildroot}%{_rpmconfigdir}
install -m 0755 %{SOURCE16} %{buildroot}%{_rpmconfigdir}

mkdir -p %{buildroot}/usr/lib/rpm/fileattrs
install -m 0644 %{SOURCE17} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0644 %{SOURCE18} %{buildroot}%{_rpmconfigdir}/fileattrs/
install -m 0644 %{SOURCE19} %{buildroot}%{_rpmconfigdir}/fileattrs/

mkdir -p %{buildroot}%{_datadir}/mingw
install -m 0644 %{SOURCE13} %{buildroot}%{_datadir}/mingw/
install -m 0644 %{SOURCE14} %{buildroot}%{_datadir}/mingw/
install -m 0644 %{SOURCE15} %{buildroot}%{_datadir}/mingw/
install -m 0644 %{SOURCE20} %{buildroot}%{_datadir}/mingw/
install -m 0644 %{SOURCE21} %{buildroot}%{_datadir}/mingw/
install -m 0644 %{SOURCE22} %{buildroot}%{_datadir}/mingw/

mkdir -p %{buildroot}%{pkgconfig_personalitydir}
install -m 0644 %{SOURCE23} %{buildroot}%{pkgconfig_personalitydir}/i686-w64-mingw32.personality
install -m 0644 %{SOURCE24} %{buildroot}%{pkgconfig_personalitydir}/x86_64-w64-mingw32.personality
install -m 0644 %{SOURCE25} %{buildroot}%{pkgconfig_personalitydir}/x86_64-w64-mingw32ucrt.personality

mkdir -p %{buildroot}%{_sysconfdir}/ld.so.conf.d
install -m 0644 %{SOURCE26} %{buildroot}%{_sysconfdir}/ld.so.conf.d/mingw32-hostlib.conf
install -m 0644 %{SOURCE27} %{buildroot}%{_sysconfdir}/ld.so.conf.d/mingw64-hostlib.conf

# Link mingw-pkg-config man pages to pkgconf(1)
mkdir -p %{buildroot}%{_mandir}/man1/
echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/i686-w64-mingw32-pkg-config.1
echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/x86_64-w64-mingw32-pkg-config.1
echo ".so man1/pkgconf.1" > %{buildroot}%{_mandir}/man1/x86_64-w64-mingw32ucrt-pkg-config.1


%files base
%doc COPYING
%dir %{_sysconfdir}/rpmlint/
%config(noreplace) %{_sysconfdir}/rpmlint/mingw-rpmlint.config
%{macrosdir}/macros.mingw
%{_libexecdir}/mingw-scripts
%{_rpmconfigdir}/mingw*
%dir %{_datadir}/mingw/

%files -n mingw32-filesystem
%{macrosdir}/macros.mingw32
%config(noreplace) %{_sysconfdir}/profile.d/mingw32.sh
%{_bindir}/mingw32-configure
%{_bindir}/mingw32-cmake
%{_bindir}/mingw32-make
%{_bindir}/mingw32-meson
%{_bindir}/mingw32-pkg-config
%{_bindir}/i686-w64-mingw32-pkg-config
%{_prefix}/i686-w64-mingw32
%{_rpmconfigdir}/fileattrs/mingw32.attr
%{_datadir}/mingw/toolchain-mingw32.cmake
%{_datadir}/mingw/toolchain-mingw32.meson
%{pkgconfig_personalitydir}/i686-w64-mingw32.personality
%{_mandir}/man1/i686-w64-mingw32-pkg-config.1*
%{_sysconfdir}/ld.so.conf.d/mingw32-hostlib.conf
%dir %{_prefix}/lib/debug/%{_prefix}
%dir %{_prefix}/lib/debug/%{_prefix}/i686-w64-mingw32


%files -n mingw64-filesystem
%{macrosdir}/macros.mingw64
%config(noreplace) %{_sysconfdir}/profile.d/mingw64.sh
%{_bindir}/mingw64-configure
%{_bindir}/mingw64-cmake
%{_bindir}/mingw64-make
%{_bindir}/mingw64-meson
%{_bindir}/mingw64-pkg-config
%{_bindir}/x86_64-w64-mingw32-pkg-config
%{_prefix}/x86_64-w64-mingw32
%{_rpmconfigdir}/fileattrs/mingw64.attr
%{_datadir}/mingw/toolchain-mingw64.cmake
%{_datadir}/mingw/toolchain-mingw64.meson
%{pkgconfig_personalitydir}/x86_64-w64-mingw32.personality
%{_mandir}/man1/x86_64-w64-mingw32-pkg-config.1*
%{_sysconfdir}/ld.so.conf.d/mingw64-hostlib.conf
%dir %{_prefix}/lib/debug/%{_prefix}
%dir %{_prefix}/lib/debug/%{_prefix}/x86_64-w64-mingw32

%files -n ucrt64-filesystem
%{macrosdir}/macros.ucrt64
%config(noreplace) %{_sysconfdir}/profile.d/ucrt64.sh
%{_bindir}/ucrt64-configure
%{_bindir}/ucrt64-cmake
%{_bindir}/ucrt64-make
%{_bindir}/ucrt64-meson
%{_bindir}/ucrt64-pkg-config
%{_bindir}/x86_64-w64-mingw32ucrt-pkg-config
%{_prefix}/x86_64-w64-mingw32ucrt
%{_rpmconfigdir}/fileattrs/ucrt64.attr
%{_datadir}/mingw/toolchain-ucrt64.cmake
%{_datadir}/mingw/toolchain-ucrt64.meson
%{pkgconfig_personalitydir}/x86_64-w64-mingw32ucrt.personality
%{_mandir}/man1/x86_64-w64-mingw32ucrt-pkg-config.1*
%dir %{_prefix}/lib/debug/%{_prefix}
%dir %{_prefix}/lib/debug/%{_prefix}/x86_64-w64-mingw32ucrt



%changelog
* Tue Sep 26 2023 tv <tv> 148-1.mga10
+ Revision: 1991144
- Add pkgconfig provides
- Add dependency on cmake-rpm-macros
- Set mingw_env before in run_mingw_make
- Set RUSTFLAGS in mingw env

* Mon Jan 02 2023 tv <tv> 145-2.mga9
+ Revision: 1929126
- Use upstream fix for mingw-find-lang.sh exit code
- Add mingw-qmake-qt6 macros, drop mingw-cmake-kde4 macros

* Thu Dec 22 2022 pterjan <pterjan> 143-2.mga9
+ Revision: 1925942
- Fix mingw-find-lang.sh which was breaking a bunch of mingw-* packages

* Sat Dec 10 2022 tv <tv> 143-1.mga9
+ Revision: 1920284
- Prevent mingw-find-lang.sh from clobbering previous find-lang results

* Thu Oct 20 2022 tv <tv> 142-1.mga9
+ Revision: 1897919
- Require mingw-binutils-generic

* Wed Oct 12 2022 tv <tv> 141-2.mga9
+ Revision: 1896521
- Replace egrep with grep -E

* Sun Aug 14 2022 tv <tv> 141-1.mga9
+ Revision: 1877583
- 141
- Explain the build order

* Sun May 22 2022 tv <tv> 139-1.mga9
+ Revision: 1859752
- Set CMAKE_FIND_ROOT_PATH_MODE_PACKAGE in cmake toolchain files
- Drop CMAKE_INSTALL_LIBDIR from mingw-cmake macros

* Tue May 10 2022 tv <tv> 137-1.mga9
+ Revision: 1857343
- Include glib-mkenums in the toolchain binaries to avoid installing host GLib for building.

* Sun May 08 2022 tv <tv> 136-1.mga9
+ Revision: 1856729
- Drop standard DLL provides, moved to mingw-crt

* Sat May 07 2022 tv <tv> 135-1.mga9
+ Revision: 1856610
- Add host lib dirs to ld.so.conf

* Sun May 01 2022 tv <tv> 134-1.mga9
+ Revision: 1855302
- Regenerate standard-dlls

* Tue Mar 01 2022 tv <tv> 133-2.mga9
+ Revision: 1787029
- Fix ucrt64 toolchain filenames.

* Thu Feb 24 2022 tv <tv> 133-1.mga9
+ Revision: 1784044
- Add ucrt64 target (rhbz#2055254)
- Create build_winXX directories with mkdir -p

* Fri Feb 11 2022 tv <tv> 131-1.mga9
+ Revision: 1772987
- Move python dependency generation to mingw32/64_python3.attr in mingw-python3 package
- More generic mingw_pkg_name macros to also deduce mingw package name from native name

* Thu Feb 03 2022 tv <tv> 130-1.mga9
+ Revision: 1771190
- Drop evaling $@ in mingw-scripts, ensure mingw macros invoked by mingw-scripts contain $@

* Sun Jan 23 2022 tv <tv> 129-1.mga9
+ Revision: 1769478
- Also set FCFLAGS in mingw-env

* Sun Jan 09 2022 tv <tv> 128-1.mga9
+ Revision: 1767355
- Add Boost_ARCHITECTURE to cmake toolchain file
- Correctly test whether CC/CXX/FC env-vars are set in cmake toolchain config

* Fri Dec 17 2021 tv <tv> 126-1.mga9
+ Revision: 1762299
- Preserve CC/CXX/FC/RC set by ENV if set in cmake toolchain files

* Mon Nov 22 2021 tv <tv> 125-1.mga9
+ Revision: 1758542
- Fix up debug dirs ownership

* Thu Nov 18 2021 tv <tv> 124-1.mga9
+ Revision: 1757649
- Use relative paths in cmake/meson toolchain files to make ccache work if
  available

* Fri Oct 22 2021 tv <tv> 123-1.mga9
+ Revision: 1752599
- Autogenerate mingw-python3 BR
- Fix mingw{32/64}.attr to also capture pyd, pc files
- Allow overriding CMake INCLUDE_INSTALL_DIR in MINGWXX_CMAKE_ARGS
- Drop evaling $@ in mingw-scripts, ensure mingw macros invoked by mingw-scripts contain $@
- Drop use of deprecated external dependency generator
- Fix file listed twice
- Fix copying minidebug symbols to binary in mingw-find-debuginfo.sh
- Adapt mingw-find-debuginfo.sh to store debug files below /usr/lib/debug
  See https://fedoraproject.org/wiki/Changes/F36MingwDebugLocation
- Use pkgconf for pkgconfig
- Allow overriding CFLAGS/CXXFLAGS/LDFLAGS for %%mingw_meson

* Sun Feb 28 2021 daviddavid <daviddavid> 117-1.mga9
+ Revision: 1693357
- filter Windows API umbrella libraries from requires

* Tue Dec 22 2020 wally <wally> 116-4.mga8
+ Revision: 1662933
- use _legacy_common_support macro with mingw cflags

* Thu Nov 26 2020 wally <wally> 116-3.mga8
+ Revision: 1649563
- mageiafy %%_configure_gnuconfig_hack usage in mingw rpm macros

* Fri Sep 11 2020 tv <tv> 116-2.mga8
+ Revision: 1624442
- add more provides
- Requires rpm-mageia-setup
- 116

* Sun May 24 2020 daviddavid <daviddavid> 113-1.mga8
+ Revision: 1587228
- add %%mingw_make_build and %%mingw_make_install
- fix %%mingw_meson resulting in ERROR: Unable to determine dynamic linker
- quote tr sequences like '[blank]' to prevent the shell from doing so (#1830233)

* Sun Feb 16 2020 umeabot <umeabot> 109-2.mga8
+ Revision: 1530500
- Mageia 8 Mass Rebuild

* Fri Aug 30 2019 daviddavid <daviddavid> 109-1.mga8
+ Revision: 1435264
- Add dlltool to toolchain-mingw{32,64}.meson

* Tue Aug 27 2019 daviddavid <daviddavid> 108-1.mga8
+ Revision: 1434591
- Fix mingw-find-debuginfo.sh to pick up strippable binaries also
  in %%{_prefix}/%%{mingw32,64_target}

* Sat Jul 06 2019 daviddavid <daviddavid> 107-1.mga8
+ Revision: 1419045
- add %%mingw_ninja_install macro

* Sat Mar 16 2019 daviddavid <daviddavid> 106-1.mga7
+ Revision: 1378011
- new version: 106

* Tue Jan 01 2019 daviddavid <daviddavid> 104-1.mga7
+ Revision: 1348164
- add macros for meson and ninja

* Thu Sep 20 2018 umeabot <umeabot> 103-2.mga7
+ Revision: 1279590
- Mageia 7 Mass Rebuild

* Tue Sep 19 2017 tv <tv> 103-1.mga7
+ Revision: 1155675
- Add %%mingw_nm macro
- Also extract debuginfo data from pyd binaries

* Wed May 11 2016 tv <tv> 101-1.mga6
+ Revision: 1012438
- new release

* Sun Feb 28 2016 neoclust <neoclust> 100-3.mga6
+ Revision: 980573
- Sync with fedora 24

* Fri Feb 05 2016 umeabot <umeabot> 99-6.mga6
+ Revision: 939864
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 99-5.mga5
+ Revision: 744893
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 99-4.mga5
+ Revision: 682429
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 99-3.mga4
+ Revision: 536105
- Mageia 4 Mass Rebuild

* Sun Sep 22 2013 neoclust <neoclust> 99-2.mga4
+ Revision: 483361
- Manually add provides

* Sun Sep 22 2013 neoclust <neoclust> 99-1.mga4
+ Revision: 483112
- Own the folders %%{mingw32_libdir}/cmake and %%{mingw64_libdir}/cmake
- Own all the locale folders below %%{mingw32_datadir}/locale and %%{mingw64_datadir}/locale (RHBZ #798329)
- Remove invalid macros with '++' in the name
- Only set the environment variable PKG_CONFIG_LIBDIR when using the macros %%mingw32_cmake, %%mingw32_cmake_kde4,
    %%mingw64_cmake or %%mingw64_cmake_kde4
- Removed the use of the environment variable PKG_CONFIG_LIBDIR While building binaries the tool {i686,x86_64}-
    w64-mingw32-pkg-config should be used to find out pkg-config information The environment variable PKG_CONFIG
    already automatically points to the right cross-compiler aware version of pkg-config when the mingw{32,64}-pkg-
    config packages are installed
- Fixes compilation of mingw-gtk3 3.9.0 (GNOME BZ #699690)
- Automatically add R: mingw{32,64}-pkg-config tags when .pc files are detected while building mingw packages
- Updated the list of DLLs which are part of the Win32 API with the libraries d3dcompiler_46.dll, d3dcsx_46.dll,
    davclnt.dll, devmgr.dll, devobj.dll and devrtl.dll
- imported package mingw-filesystem

